.left margin
.if not HLP
.hl 1 Display Commands
.endif hlp
.helpc DISPLAY
.br
The display commands control how numbers such as the page number, chapter
number, and so on, are displayed.  Numbers
can be displayed as normal (decimal) numbers, letters, or Roman numerals.
Extra text can be added to the numbers as pre- or post-fixes.
.ifnot small
Pre- and post-fixes can be used to automatically control the format
of various headers.  For example, you can automatically underline headers,
or print them in boldface on printers that support bolding.
The display commands, like the DSR commands, produce a break.
.if hlp
.if RSX
.nj.i5;ADDITIONAL HELP AVAILABLE:
.dhy.ts+10, +10, +10, +10, +10, +10
format	pre-fix	NUMBER	APPENDIX	CHAPTER	ELEMENTS
	LEVELS	SUBPAGE	SUBTITLE	TITLE	TOC__PAGE
.j.ehy
.endif rsx
.endif hlp
.HELPD FORMAT
.br
.endif small
.s2.nf.ts 20,30 .text
.c;Table of Formats
.s
The format code produces numbers in the specified format:
.s
        ^&Format        Description\& 
.s 
        D	Decimal numbers
		(1,2,3,....)
        LU      Letters uppercase
		(A,B,C,....,Z,AA,AB,AC....)
        LL      Letters lowercase
		(a,b,c,....,z,aa,ab,ac....)
        LM      Letters mixed (first is uppercase) 
		(A,B,C,....,Z,Aa,Ab,...)
        RU      Roman numerals uppercase 
		(I,II,III,IV,....)
        RL      Roman lowercase 
		(i,ii,iii,iv,....)
        RM      Roman mixed 
		(I,Ii,Iii,Iv,....)
.etx.F 
.ifnot small
.HELPD PRE-FIX
.s.c;Pre/Post-fix
.s
The pre- or post-fix specifies text to be printed before or after the
number. The value is specified as a literal of up to $PRE$ characters.
Any flag characters included in the pre- or post-fix text are interpreted at
the time the page is printed.  The autoindex flag is ignored in the pre-fix
and tabs are converted to spaces. All spaces are treated as non-expandable. 
.x space>non-expandable
The pre-fix size can be extended by a substitution.  When this is done,
the number of levels of substitution is reduced, since the pre/post-fix is
essentially another level of substitution. The pre- or post-fixes can
be enclosed in either apostrophes (') or quotes ("). See the rules applicable
to literal parameters. 
.i5;DSR doesn't support the "pre-fix" or "post-fix" parameters.
.helpd  APPENDIX
.endif small
.q _.DISPLAY APPENDIX ["pre-fix",] [format] [,"post-fix"]
.qq _.DAX ["pre-fix",] [format] [,"post-fix"]
.ifnot small .s.x DISPLAY >APPENDIX 
controls the format of the appendix number.
The pre/post-fixes apply only to the first page of the appendix, but
the format sets the style of the appendix number, page number,
index, and header levels.  The page number and index are only changed if
chapter numbering is used. 
.p
.endif small
.i5;DEFAULT: _.DISPLAY APPENDIX "APPENDIX " , LU , ""
.ifnot small
.helpd CHAPTER
.endif small
.q _.DISPLAY CHAPTER ["pre-fix",] [format] [,"post-fix"]
.qq _.DCH ["pre-fix",] [format] [,"post-fix"]
.ifnot small .s.x DISPLAY >CHAPTER 
controls the printed format of the chapter numbers when the _.CHAPTER
command is used. The command determines what is printed before and after the
chapter number on the title page of each chapter. 
.p;
.endif small
.i5;DEFAULT: _.DISPLAY CHAPTER "CHAPTER " , D , ""
.ifnot small
.p
For example, if you want sections to be numbered with Roman numerals rather
than chapters, include the following in your _.RNO file:
.i5;_.DISPLAY 'Section (' , RU , ')'
.br;When you issue the _.CHAPTER command for the 6'th time, you will get the
following chapter header: 
.i5;Section (VI)
.helpd ELEMENTS
.endif small
.iif spr86 .bb
.q _.DISPLAY ELEMENTS ["pre-fix",] [format] [,"post-fix"] 
.qq _.DLE ["prefix",] [format] [,"post-fix"] 
.iif spr86 .eb
.ifnot small .s.x DISPLAY >ELEMENTS
sets the format of the current LIST element.  "l" and "r" are
the left and right characters to put around the list number.  See  _.LIST,
_.LIST ELEMENT, _.END LIST for explanations of the list elements. 
Once you have specified the display characteristics for a given list,
the same characteristics will remain specified when additional _.LIST
or _.END LIST commands are encountered. The optional characters can be
delimited by either quotes ["] or a pair of apostrophes ['].  
.endif small
.i5;DEFAULT: _.DISPLAY ELEMENTS "" , D , "."
.ifnot small
.br; If you wish to set up lists at the beginning of the document to
normal outline form, issue the following commands:
.i5;_.LIST 0 _.LIST 0 _.DISPLAY ELEMENTS LU
.i5;_.LIST 0 _.DISPLAY ELEMENTS LL
.I5;_.END LIST 0 _.END LIST 0 _.END LIST 0
.br;This will display lists in the form (decimal number, capital letter,
lowercase letter).
.helpd LEVELS
.endif small
.q _.DISPLAY LEVELS [fm1,][fm2,][fm3,][fm4,][fm5,][fm6,]
.qq _.DISPLAY LEVELS [level,]["pre-fix",] [form,] ["post-fix"]
.qq _.DHL [fm1,][fm2,][fm3,][fm4,][fm5,][fm6,]
.ifnot small .s.x DISPLAY >LEVELS 
specifies the format for display of the header level numbers.
fm1 to fm6 are format codes for LEVELS 1 to 6. 
Each format code can be preceded by a pre-fix and followed by a post-fix.
The pre-fix and post-fix are $PRE$ char literals that will appear before and
after the numbers.
If the number is not printed, the post-fix is omitted. When the pre-
and post-fix are defined, the _.HEADER LEVEL command will automatically turn
off underlining and all printer special features before the pre-fix and after
the label. The levels can be specified by number or sequentially.
For example, the following command will set number underlining with uppercase
letters for level 2 and title underlining with roman numerals for level 3:
.i5;_.DISPLAY LEVELS 2,"_^_&",LU,"_\_&",RU,"_^_&"
.i5;(DSR doesn't support Level numbers, pre-fix or post-fix)
.endif small
.i5;DEFAULT: _.DISPLAY LEVELS D,D,D,D,D,D
.ifnot small
.helpd NUMBER
.endif small
.q _.DISPLAY NUMBER ["pre-fix",] [format] [,"post-fix"]
.qq _.DNM ["pre-fix",] [format] [,"post-fix"]
.ifnot small .s.x DISPLAY >NUMBER 
controls the format of the page numbers printed at the top of the page
and in the index and table of contents. The pre- and post-fixes
specify text to be printed before and after the page number.  The pre-fix and
post-fix are only printed on the individual pages, and do not appear in the
index or table of contents page numbers. The format applies to the page
number, which can be either a regular decimal number, Roman numeral, or
a letter. See the table of formats. If the format is not specified,
then it remains unchanged. If you wish to specify the post-fix only, you
must either specify the pre-fix, the format, or include commas to mark their
absence. 
.endif small
.i5;DEFAULT: _.DISPLAY NUMBER "Page " , D , ""
.ifnot small
.if hlp
.if RSX
.br;Further help: example
.endif rsx
.endif hlp
.HELPE EXAMPLE
.p
If you want pages to be numbered in lower case roman numerals, you
would use the following command:
.i5;_.DISPLAY NUMBER  RL
.p
If you wish to print a 4 page memorandum,  and on each page you want the
page number and the total number of pages as n/4 underlined, you would
issue the following command:
.i5;_.DISPLAY NUMBER "_^_&" "/4_\_&"
.br; The first page is numbered ^&1/1\&, the second ^&1/2\&, and so on.
.p;The RUNOFF manual was produced with the following format:
.i5;_.DISPLAY NUMBER "- " " -".
.helpd SUBPAGE
.endif small
.q _.DISPLAY SUBPAGE [format] 
.qq _.DSP [format] 
.ifnot small .s.x DISPLAY >SUBPAGE 
controls the format of the subpage number.  
.endif small
.i5;DEFAULT: _.DISPLAY SUBPAGE "" LU ""
.ifnot small
.helpd SUBTITLE
.endif small
.q _.DISPLAY SUBTITLE ["pre-fix"] [,"post-fix"]
.ifnot small .s.x DISPLAY>SUBTITLE
sets pre- and post-fixes that are to appear with the subtitle at the top
of the page.  The _.DISPLAY SUBTITLE command must appear before the _.SUBTITLE
command or _.HEADER LEVEL command that it modifies. The _.HEADER LEVEL command
produces automatic subtitles if _.AUTOSUBTITLE is on. 
.endif small
.i5;DEFAULT: _.DISPLAY SUBTITLE "" ""
.ifnot small
.helpd TITLE
.endif small
.q _.DISPLAY TITLE ["pre-fix"] [,"post-fix"]
.ifnot small .s.x DISPLAY>TITLE
sets pre- and post-fixes that are to appear with the title at the
top of the page.  The _.DISPLAY TITLE command must appear before the _.TITLE
command or _.CHAPTER command that it modifies.
The _.CHAPTER command produces automatic titles if _.AUTOTITLE is on.
.endif small
.i5;DEFAULT: _.DISPLAY TITLE "" ""
.helpd TOC__PAGE
.iif spr86 .bb
.q _.DISPLAY TOC PAGE ["pre-fix"] [,"post-fix"]
.s.x DISPLAY>TOC PAGE
This command sets pre- and post-fixes that are to appear with the page number in
the .RNT file.  
.ifnot small
This modifies the format of the page numbers as they appear along the right
margin of the table of contents. The format of the page number is also
controlled by _.DISPLAY NUMBER, _.DISPLAY SUBPAGE, _.DISPLAY CHAPTER, and
_.DISPLAY APPENDIX.  The page numbers at the top and bottom of the table of
contents are not modified by this command. 
.endif small
.iif spr86 .eb
.lm
